@@ -1,7 +1,7 @@
 package Bot::ChatBots::Role::WebHook;
 use strict;
 use warnings;
-{ our $VERSION = '0.008'; }
+{ our $VERSION = '0.010'; }
 
 use Ouch;
 use Mojo::URL;
@@ -13,7 +13,6 @@ use Try::Tiny;
 use Moo::Role;
 
 with 'Bot::ChatBots::Role::Source';
-requires 'parse_request';
 requires 'process_updates';
 
 has app => (
@@ -132,7 +131,13 @@ sub install_route {
    my $method = lc($args->{method} // $self->method // 'post');
    my $r      = $args->{routes} // $self->app->routes;
    my $p      = $args->{path} // $self->path;
-   return $r->$method($p => $self->handler($args));
+   my $h      = $args->{handler} // $self->handler($args);
+   return $r->$method($p => $h);
 } ## end sub install_route
 
+sub parse_request { # most APIs rely on JSON... let's leverage this
+   my ($self, $req) = @_;
+   return $req->json;
+}
+
 1;
